@@ -292,7 +292,7 @@ static inline void bit2_to_bit2rev(const char *bit2_ptr,
       bit2rev_prt[bit2_i] = rcur_byte;
     }
 
-  if (bit2_n & 0x1 == 1) {
+  if ((bit2_n & 0x1) == 1) {
     lcur_byte = 0;
     for (bitpos = 6; bitpos >= 0; bitpos -= 2) {
       lcur_byte |= ((bit2_ptr[half] >> (bitpos)) & 0x3) << (6-bitpos);
