@@ -446,7 +446,7 @@ def make_csfasta(lib, fragment, buf_cs, buf_qual, f, flowcell,
         for row_i in _progress_bar_iter(xrange(a.shape[0]), suffix = ' tile: %i'%(tile_i+1)): 
             seq, qual = colourqual_frombuffer(a[row_i])
             seq = bytearray_addint(seq, 48)
-            qual = bytearray_phredtoascii(qual)
+            
             x,y = xyloc[row_i]
             buf_cs.write(seq_id %(x,y))
             buf_cs.write('\n')
@@ -456,7 +456,7 @@ def make_csfasta(lib, fragment, buf_cs, buf_qual, f, flowcell,
 
             buf_qual.write(seq_id %(x,y))
             buf_qual.write('\n')
-            buf_qual.write(qual)
+            buf_qual.write(' '.join( str(q) for q in qual))
             buf_qual.write('\n')
 
     if os.isatty(out.fileno()):
@@ -582,12 +582,13 @@ def fastqual(xsqlib, fragment, what, sample = 0.05):
 
 
 from ngs_plumbing import report
-import csv
+import csv, json
 import jinja2
 
 def make_htmlreport(xsqfile, directory = '.', verbose = True,
-                    sample_percent = 0.05):
+                    sample_percent = 0.05, data_type = 'json'):
     assert(isinstance(xsqfile, XSQFile))
+    assert(data_type in ('json', 'csv'))
     pl = jinja2.PackageLoader('ngs_plumbing', 
                               package_path = os.path.join('data', 'html', 
                                                           'templates'));
@@ -599,7 +600,7 @@ def make_htmlreport(xsqfile, directory = '.', verbose = True,
     LibReport = namedtuple("LibReport", 
                            "name lib_i readcount fragments")
     FragmentReport = namedtuple("FragmentReport",
-                                "name csv_fn ")
+                                "name data_fn")
     libs = list()
     for lib_i, lib in enumerate(xsqfile.iter_lib()):
         if verbose:
@@ -610,23 +611,32 @@ def make_htmlreport(xsqfile, directory = '.', verbose = True,
             #FIXME: only consider colour space for now
             fq = fastqual(lib, fragment, 'ColorCallQV', sample = sample_percent)
             # build the CSV file with quality
-            csv_fn = os.path.join(directory, 
-                                  'fastqual_%s_%s_%i.csv' % (lib.name, fragment, lib_i))
+            data_fn = os.path.join(directory, 
+                                  'fastqual_%s_%s_%i.%s' % (lib.name, fragment, lib_i, data_type))
             if verbose:
-                sys.stdout.write('Creating file %s...' % csv_fn)
-            f = file(csv_fn, mode = 'w')
-            csv_w = csv.writer(f)
-            for row in report.fastqual_tocsv_iter(fq):
-                csv_w.writerow(row)
+                sys.stdout.write('Creating file %s...' % data_fn)
+            f = file(data_fn, mode = 'w')
+            if data_type == 'csv':
+                csv_w = csv.writer(f)
+                for row in report.fastqual_tocsv_iter(fq):
+                    csv_w.writerow(row)
+            else:
+                # json
+                tmp = report.fastqual_tojson(fq)
+                f.write('dataf_%i_%s = ' % (lib_i, fragment) )
+                f.write(tmp)
+                f.write(';')
             f.close()
             if verbose:
                 sys.stdout.write('done.\n')
-            frags.append(FragmentReport(fragment, csv_fn))
+            frags.append(FragmentReport(fragment, os.path.relpath(data_fn, start = directory)))
         libs.append(LibReport(lib.name, lib_i, 
                               lib.readcount(), frags))
             
     # render the HTML
     rd = template.render(**{
+            'basequal_max': 33,
+            'data_type': data_type,
             'filename': os.path.basename(xsqfile.filename),
             'xsqinfo': tuple(xsqinfo.iteritems()),
             'libs': libs,
