@@ -78,6 +78,13 @@ def main():
         os.mkdir(options.dest_dir)
         
     for f in options.paths:
+        xsq_fn = os.path.basename(f)
+        sep_i = xsq_fn.rfind(os.path.extsep)
+        if sep_i == -1 or (sep_i == (len(xsq_fn) - 1)) or (xsq_fn[(sep_i+1):].lower() != 'xsq'):
+            print('XSQ files are expected to have the extension XSQ.')
+            sys.exit(1)
+        dest_dir = os.path.join(options.dest_dir, xsq_fn[:sep_i])
+        os.mkdir(dest_dir)
         if options.want_info:
             xf = xsq.XSQFile(f)
             try:
@@ -96,14 +103,14 @@ def main():
             xf.close()
 
         if options.to_csfasta:
-            xsq.automagic_csfasta(f, path_out = options.dest_dir,
+            xsq.automagic_csfasta(f, path_out = dest_dir,
                                   fragment = None, 
                                   buf_size = long(2E6), 
                                   out = sys.stdout)
         if options.to_fastq:
             if options.use_ecc:
                 try:
-                    xsq.automagic_fastq(f, path_out = options.dest_dir, 
+                    xsq.automagic_fastq(f, path_out = dest_dir, 
                                         fragment = None, 
                                         buf_size = long(2E6), 
                                         out = sys.stdout)
@@ -135,6 +142,10 @@ def htmlreport():
                         default = 0.05,
                         type = float,
                         help = 'Percentage of the data to sample (a number between 0 and 1, default: 0.05, that is 5%%).')
+    parser.add_argument('-t', '--data-type',
+                        dest = 'data_type',
+                        default = 'json',
+                        help='Data type (default: json).')
     parser.add_argument('-V', '--version',
                         action = 'version',
                         version = ngs_plumbing.__version__)
@@ -156,10 +167,19 @@ def htmlreport():
             print('Error: destination directory does not exist.')
             sys.exit(1)
             
+    xsq_fn = os.path.basename(f)
+    sep_i = xsq_fn.rfind(os.path.extsep)
+    if sep_i == -1 or (sep_i == (len(xsq_fn) - 1)) or (xsq_fn[(sep_i+1):].lower() != 'xsq'):
+        print('XSQ files are expected to have the extension XSQ.')
+        sys.exit(1)
+    dest_dir = os.path.join(options.dest_dir, xsq_fn[:sep_i])
+    os.mkdir(dest_dir)
+
     for f in options.paths:
         xf = xsq.XSQFile(f)
-        xsq.make_htmlreport(xf, directory = options.dest_dir,
-                            sample_percent = options.sample_percent)
+        xsq.make_htmlreport(xf, directory = dest_dir,
+                            sample_percent = options.sample_percent,
+                            data_type = options.data_type)
         xf.close()
 
 if __name__ == '__main__':
